package cn.com.qmth.stmms.biz.utils;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

public class TaskLockUtil {

    // 评卷任务并发处理互斥锁
    private static Map<String, TaskLock> formalTaskMap = new ConcurrentHashMap<>();

    // 试评任务并发处理互斥锁
    private static Map<String, TaskLock> trialTaskMap = new ConcurrentHashMap<>();

    public static void clearTimeoutTask(long timeoutMinute) {
        synchronized (TaskLockUtil.class) {
            if (formalTaskMap.size() > 0) {
                for (String key : formalTaskMap.keySet()) {
                    TaskLock taskLock = formalTaskMap.get(key);
                    if (taskLock != null) {
                        taskLock.clear(timeoutMinute);
                    }
                }
            }
            if (trialTaskMap.size() > 0) {
                for (String key : trialTaskMap.keySet()) {
                    TaskLock taskLock = trialTaskMap.get(key);
                    if (taskLock != null) {
                        taskLock.clear(timeoutMinute);
                    }
                }
            }
        }
    }

    public static TaskLock getTrialTask(String key) {
        return trialTaskMap.get(key) == null ? new TaskLock() : trialTaskMap.get(key);
    }

    public static TaskLock getFormalTask(String key) {
        return formalTaskMap.get(key) == null ? new TaskLock() : formalTaskMap.get(key);
    }

    public static void addFormalTask(String key, TaskLock value) {
        synchronized (TaskLockUtil.class) {
            formalTaskMap.put(key, value);
        }
    }

    public static void addTrialTask(String key, TaskLock value) {
        synchronized (TaskLockUtil.class) {
            trialTaskMap.put(key, value);
        }
    }
}
